@@ -7,7 +7,7 @@ given a 'template' string and a 'dictionary' of parameters and values.
 import enum
 import os
 import re
-from typing import Any, Dict, List, Optional, Pattern, Tuple
+from typing import Any, Dict, List, Optional, Pattern, Set, Tuple
 
 import jsonschema
 import yaml
@@ -211,6 +211,93 @@ def get_job_doc_url(
     return doc_url
 
 
+def get_pull_secret_names(job_definition: Dict[str, Any]) -> Set[str]:
+    """Given a Job definition this function returns the unique list of the
+    pull-secrets declared.
+    """
+    names: Set[str] = set()
+
+    # Check the environment block...
+    pull_secret: Optional[str] = job_definition.get("image", {}).get("pull-secret")
+    if pull_secret:
+        names.add(pull_secret)
+
+    return names
+
+
+def get_asset_names(job_definition: Dict[str, Any]) -> Set[str]:
+    """Given a Job definition this function returns the unique list of all the
+    asset names declared. Asset names can be used in image environment
+    variables and files.
+    """
+    asset_names: Set[str] = set()
+
+    # Check the environment block...
+    environment: List[Dict[str, Any]] = job_definition.get("image", {}).get(
+        "environment", []
+    )
+    for env in environment:
+        if "account-server-asset" in env["value-from"]:
+            asset_names.add(env["value-from"]["account-server-asset"]["name"])
+    # Check the file block...
+    file_block: List[Dict[str, Any]] = job_definition.get("image", {}).get("file", [])
+    for item in file_block:
+        if "account-server-asset" in item["content-from"]:
+            asset_names.add(item["content-from"]["account-server-asset"]["name"])
+
+    return asset_names
+
+
+def get_file_assets(job_definition: Dict[str, Any]) -> List[Dict[str, str]]:
+    """Given a Job definition this function returns the list of all the
+    file-based assets declared. What's returned is the asset 'name' and the
+    'image file' the asset is expected to be mapped to.
+
+    In order to get the asset the caller will need to interact with the
+    Account Server (AS), what is returned here is the asset name, not the asset.
+    """
+    file_assets: List[Dict[str, str]] = []
+
+    # Iterate through the file block...
+    file_block: List[Dict[str, Any]] = job_definition.get("image", {}).get("file", [])
+    for item in file_block:
+        if "account-server-asset" in item["content-from"]:
+            file_assets.append(
+                {
+                    "asset": item["content-from"]["account-server-asset"]["name"],
+                    "image-file": item["name"],
+                }
+            )
+
+    return file_assets
+
+
+def get_environment_assets(job_definition: Dict[str, Any]) -> List[Dict[str, str]]:
+    """Given a Job definition this function returns the list of all the
+    environment-based assets declared. What's returned is the asset 'name' and the
+    environment 'variable' the asset is expected to be mapped to.
+
+    In order to get the asset the caller will need to interact with the
+    Account Server (AS), what is returned here is the asset name, not the asset.
+    """
+    env_assets: List[Dict[str, str]] = []
+
+    # Iterate through the environment block...
+    environment: List[Dict[str, Any]] = job_definition.get("image", {}).get(
+        "environment", []
+    )
+    for item in environment:
+        if "account-server-asset" in item["value-from"]:
+            env_assets.append(
+                {
+                    "asset": item["value-from"]["account-server-asset"]["name"],
+                    "variable": item["name"],
+                }
+            )
+
+    return env_assets
+
+
 def decode(
     template_text: str,
     variable_map: Optional[Dict[str, str]],
